pub fn detect_path_separator(input: &str) -> PathSeparatorExpand description
Detects which path separator style appears in the input.
pub fn detect_path_separator(input: &str) -> PathSeparatorDetects which path separator style appears in the input.